@@ -115,6 +115,8 @@ class ConfigValidation(object):
                              'reject_spf': (Sequence, False),
                              'lookup_senders': (Mapping, False),
                              'lookup_recipients': (Mapping, False),
+                             'only_senders': (Sequence, False),
+                             'only_recipients': (Sequence, False),
                              'lookup_credentials': (Mapping, False),
                              'reject_spam': (Mapping, False)}
             self._check_keys(opts.rules, rules_keydict, stack+['rules'], True)
